@@ -16,6 +16,13 @@ To build a function not included in the package, use the following template::
 import numpy as np
 
 def line(value):
+    """
+    | Line which can be used to cross with functions like RSI or MACD.
+    | Name: line\_\ **value**\ 
+
+    :param value: Value of the line
+    :type value: float
+    """
     def return_function(data):
         column_name = f'line_{value}'
         if column_name not in data.columns:
@@ -47,7 +54,8 @@ def get_column(column):
 
 def trailing(target="close", days=40, over_under="under"):
     """
-    Calculates the if the target is trailing under or over the current in the past days.
+    | Calculates the if the target is trailing under or over the current in the past days.
+    | Name: trailling\_\ **over\_under**\ \_\ **days**\ \_of\_\ **target**
 
     :param target: Data column to use for the calculation, defaults to "close"
     :type target: str
@@ -72,7 +80,9 @@ def trailing(target="close", days=40, over_under="under"):
 
 
 def rolling_std(days, target="close"):
-    """Calculates the rolling standard deviation
+    """
+    | Calculates the rolling standard deviation
+    | Name: rolling\_std\_\ **days**\ \_of\_\ **target**
 
     :param days: Size of the window in days
     :type days: int
@@ -89,7 +99,9 @@ def rolling_std(days, target="close"):
 
 
 def moving_average(days, target="close"):
-    """Calculates the rolling moving average
+    """
+    | Calculates the rolling moving average
+    | Name: moving\_average\_\ **days**\ \_of\_\ **target**
 
     :param days: Size of the window in days
     :type days: int
@@ -106,7 +118,9 @@ def moving_average(days, target="close"):
 
 
 def weighted_moving_average(days, weights):
-    """Calculates the rolling weighted moving average. The weights list should have the size of the days window.
+    """
+    | Calculates the rolling weighted moving average. The weights list should have the size of the days window.
+    | Name: weighted\_moving\_average\_\ **days**
 
     :param days: Size of the window
     :type days: int
@@ -134,7 +148,9 @@ def weighted_moving_average(days, weights):
 
 
 def step_weighting_ma(days, first_weight=1, step=1):
-    """Calculates the weighted moving average using stepped weights
+    """
+    | Calculates the weighted moving average using stepped weights
+    | Name: step\_weighting\_ma\_\ **days**
 
     :param days: Window size
     :type days: int
@@ -162,7 +178,9 @@ def step_weighting_ma(days, first_weight=1, step=1):
 
 
 def percentage_weighting_ma(days, last_weight=1, step=0.5):
-    """Calculates the weighted moving average using backwards set weights. F.e. for a given last days=3, weight=1, step=0.5, the wieghts would be [0.25, 0.5, 1]
+    """
+    | Calculates the weighted moving average using backwards set weights. F.e. for a given last days=3, weight=1, step=0.5, the wieghts would be [0.25, 0.5, 1]
+    | Name: percentage\_weighting\_ma\_\ **days**
 
     :param days: Window size
     :type days: int
@@ -193,7 +211,9 @@ def percentage_weighting_ma(days, last_weight=1, step=0.5):
 
 
 def triangular_weighting_ma(days=10, shape="linear"):
-    """Calculates the weighted moving average with the weights having a triangular shape
+    """
+    | Calculates the weighted moving average with the weights having a triangular shape
+    | Name: **shape**\ \_trianguar\_weighting\_ma\_\ **days**
 
     :param days: Window size, defaults to 10
     :type days: int, optional
@@ -266,7 +286,9 @@ def pivot_point_weighting_ma(days):
 
 
 def geometric_moving_average(days, target='close'):
-    """Calculates the geometric moving average
+    """
+    | Calculates the geometric moving average
+    | Name: geometric\_moving\_average\_\ **days**
 
     :param days: Window size
     :type days: int
@@ -285,7 +307,9 @@ def geometric_moving_average(days, target='close'):
 
 
 def exponential_smoothing(constant, target="close"):
-    """Calculates the exponential smoothing
+    """
+    | Calculates the exponential smoothing
+    | Name: exponential\_smoothing\_\ **constant**\ %\_of\_\ **target**
 
     :param constant: Smoothing constant for the calculation. Use function days_to_constant_
     :type constant: float
@@ -306,7 +330,9 @@ def exponential_smoothing(constant, target="close"):
 
 
 def second_order_exponential_smoothing(constant):
-    """Calculates the second order exponential smoothing of close
+    """
+    | Calculates the second order exponential smoothing of close
+    | Name: second\_order\_exponential\_smoothing\_\ **constant**\ %
 
     :param constant: Smoothing constant for the calculation. Use function days_to_constant_
     :type constant: float
@@ -326,7 +352,9 @@ def second_order_exponential_smoothing(constant):
 
 
 def third_order_exponential_smoothing(constant):
-    """Calculates the second order exponential smoothing of close
+    """
+    | Calculates the second order exponential smoothing of close
+    | Name: third\_order\_exponential\_smoothing\_\ **constant**\ %
 
     :param constant: Smoothing constant for the calculation. Use function days_to_constant_
     :type constant: float
@@ -363,7 +391,9 @@ def lag_correction_exponential_smoothing(constant):
 
 
 def double_moving_average(days):
-    """Calculates the double moving average of close
+    """
+    | Calculates the double moving average of close
+    | Name: double\_moving\_average\_\ **days**
 
     :param days: Window size
     :type days: int
@@ -379,7 +409,9 @@ def double_moving_average(days):
 
 
 def double_smoothed_momentum(days1, days2):
-    """Calculates the momentum, smoothed by two consecutive exponential smoothings
+    """
+    | Calculates the momentum, smoothed by two consecutive exponential smoothings
+    | Name: DSM\ **days1**\ \/\ **days2**
     
     :param days1: First smoothing window size
     :type days1: int
@@ -422,7 +454,9 @@ def regularized_exponential_ma(days, weight, target="close"):
 
 
 def hull_moving_average(period=16, target="close"):
-    """Calculates the hull moving average
+    """
+    | Calculates the hull moving average
+    | Name: hull\_moving\_average\_\ **period**\ \_of\_\ **target**
 
     :param period: Window size, defaults to 16
     :type period: int, optional
@@ -445,7 +479,9 @@ def hull_moving_average(period=16, target="close"):
 
 
 def upper_keltner_channel(days=10):
-    """Calculates the upper keltner channel
+    """
+    | Calculates the upper keltner channel
+    | Name: upper\_keltner\_\ **days**
 
     :param days: Window size, defaults to 10
     :type days: int, optional
@@ -465,7 +501,9 @@ def upper_keltner_channel(days=10):
 
 
 def lower_keltner_channel(days=10):
-    """Calculates the lower keltner channel
+    """
+    | Calculates the lower keltner channel
+    | Name: lower\_keltner\_\ **days**
 
     :param days: Window size, defaults to 10
     :type days: int, optional
@@ -485,7 +523,9 @@ def lower_keltner_channel(days=10):
 
 
 def upper_percentage_band(c, band_target, center_target):
-    """Calculates the upper percentage band
+    """
+    | Calculates the upper percentage band
+    | Name: upper\_percentage\_band\_\ **c**\ \_of\_\ **band\_target.name**\ \_over\_\ **center_target.name**
 
     :param c: multiplier constant
     :type c: float
@@ -505,7 +545,9 @@ def upper_percentage_band(c, band_target, center_target):
 
 
 def lower_percentage_band(c, band_target, center_target):
-    """Calculates the lower percentage band
+    """
+    | Calculates the lower percentage band
+    | Name: lower\_percentage\_band\_\ **c**\ \_of\_\ **band\_target.name**\ \_over\_\ **center_target.name**
 
     :param c: multiplier constant
     :type c: float
@@ -524,7 +566,9 @@ def lower_percentage_band(c, band_target, center_target):
 
 
 def upper_absolute_band(value, target):
-    """Calculates the upper absolute band
+    """
+    | Calculates the upper absolute band
+    | Name: upper\_absolute\_band\_\ **value**\ \_over\_\ **target.name**
 
     :param value: Constant for band displacement
     :type value: float
@@ -541,7 +585,9 @@ def upper_absolute_band(value, target):
 
 
 def lower_absolute_band(value, target):
-    """Calculates the lower absolute band
+    """
+    | Calculates the lower absolute band
+    | Name: lower\_absolute\_band\_\ **value**\ \_over\_\ **target.name**
 
     :param value: Constant for band displacement
     :type value: float
@@ -558,7 +604,9 @@ def lower_absolute_band(value, target):
 
 
 def upper_bollinger_band(mean_days, std_days, c):
-    """Calculates the upper bollinger band
+    """
+    | Calculates the upper bollinger band
+    | Name: upper\_bollinger\_band\_\ **mean_days**\ \/\ **std_days**
 
     :param mean_days: Window size for the band center
     :type mean_days: int
@@ -579,7 +627,9 @@ def upper_bollinger_band(mean_days, std_days, c):
 
 
 def lower_bollinger_band(mean_days, std_days, c):
-    """Calculates the lower bollinger band
+    """
+    | Calculates the lower bollinger band
+    | Name: lower\_bollinger\_band\_\ **mean_days**\ \/\ **std_days**
 
     :param mean_days: Window size for the band center
     :type mean_days: int
@@ -600,7 +650,9 @@ def lower_bollinger_band(mean_days, std_days, c):
 
 
 def upper_volatility_band(c, dev_target, band_target, center_target):
-    """Calculates the upper volatility band
+    """
+    | Calculates the upper volatility band
+    | Name: upper\_volatility\_band\_\ **c**\ \_times\_\ **band_target.name**\ &\ **dev_target.name**\ \_over\_\ **center_target.name**
 
     :param c: Multiplier constant
     :type c: float
@@ -626,7 +678,9 @@ def upper_volatility_band(c, dev_target, band_target, center_target):
 
 
 def lower_volatility_band(c, dev_target, band_target, center_target):
-    """Calculates the lower volatility band
+    """
+    | Calculates the lower volatility band
+    | Name: lower\_volatility\_band\_\ **c**\ \_times\_\ **band_target.name**\ &\ **dev_target.name**\ \_over\_\ **center_target.name**
 
     :param c: Multiplier constant
     :type c: float
@@ -652,7 +706,9 @@ def lower_volatility_band(c, dev_target, band_target, center_target):
 
 
 def momentum(days=1, target="close"):
-    """Calculates the momentum
+    """
+    | Calculates the momentum
+    | Name: momentum\_\ **days**\ \_of\_\ **target**
 
     :param days: Window size, defaults to 1
     :type days: int, optional
@@ -669,7 +725,9 @@ def momentum(days=1, target="close"):
 
 
 def momentum_percentage(days=1, target="close"):
-    """Calculates the momentum as a percentage
+    """
+    | Calculates the momentum as a percentage
+    | Name: momentum\_percentage\_\ **days**\ \_of\_\ **target**
 
     :param days: Window size, defaults to 1
     :type days: int, optional
@@ -689,7 +747,9 @@ def momentum_percentage(days=1, target="close"):
 
 
 def MACD_line(slow_trend=26, fast_trend=12):
-    """Calculates the MACD line
+    """
+    | Calculates the MACD line
+    | Name: MACD\_line\_\ **slow_trend**\ \/\ **fast_trend**
 
     :param slow_trend: Slow window size, defaults to 26
     :type slow_trend: int, optional
@@ -708,7 +768,9 @@ def MACD_line(slow_trend=26, fast_trend=12):
 
 
 def MACD_signal(signal, slow_trend=26, fast_trend=12):
-    """Calculates the MACD signal
+    """
+    | Calculates the MACD signal
+    | Name: MACD\_signal\_\ **slow_trend**\ \/\ **fast_trend**\ \/\ **signal**
 
     :param signal: Exponential smoothing window size of the MACD line
     :type signal: int
@@ -730,7 +792,9 @@ def MACD_signal(signal, slow_trend=26, fast_trend=12):
 
 
 def MACD_histogram(signal, slow_trend=26, fast_trend=12):
-    """Calculates the MACD histogram
+    """
+    | Calculates the MACD histogram
+    | Name: MACD\_histogram\_\ **slow_trend**\ \/\ **fast_trend**\ \/\ **signal**
 
     :param signal: Exponential smoothing window size of the MACD line
     :type signal: int
@@ -751,7 +815,9 @@ def MACD_histogram(signal, slow_trend=26, fast_trend=12):
 
 
 def divergence_index(slow_trend, fast_trend):
-    """Calculates the divergence index
+    """
+    | Calculates the divergence index
+    | Name: divergence\_index\_\ **slow_trend**\ \/\ **fast_trend**
 
     :param slow_trend: Slow window size
     :type slow_trend: int
@@ -773,7 +839,9 @@ def divergence_index(slow_trend, fast_trend):
 
 
 def average_true_range(days=10, target="close"):
-    """Calculates the average true range
+    """
+    | Calculates the average true range
+    | Name: average\_true\_range\_\ **days**\ \_of\_\ **target**
 
     :param days: Window size, defaults to 10
     :type days: int, optional
@@ -793,7 +861,9 @@ def average_true_range(days=10, target="close"):
 
 
 def stochastic_percentageK(days):
-    """Calculates the stochastic K
+    """
+    | Calculates the stochastic K
+    | Name: stochastic\_percentageK\_\ **days**
 
     :param days: Window size
     :type days: int
@@ -819,7 +889,9 @@ def stochastic_percentageK(days):
 
 
 def stochastic_percentageD(days, daysK):
-    """Calculates the stochastic D
+    """
+    | Calculates the stochastic D
+    | Name: stochastic\_percentageD\_\ **days**\ \/\ **daysK**
 
     :param days: Window size
     :type days: int
@@ -827,7 +899,7 @@ def stochastic_percentageD(days, daysK):
     :type daysK: int
     """
     def return_function(data):
-        column_name_K = f"stochastic_percentageK_{days}"
+        column_name_K = f"stochastic_percentageK_{daysK}"
         column_name = f"stochastic_percentageD_{days}/{daysK}"
         if column_name not in data.columns:
             stochastic_percentageK(daysK)(data)
@@ -838,7 +910,10 @@ def stochastic_percentageD(days, daysK):
 
 
 def ADoscillator():
-    """Calculates the A/D oscillator"""
+    """
+    | Calculates the A/D oscillator
+    | Name: A\/D\_oscillator
+    """
     def f(x):
         buying_power = x["high"] - x["open"]
         selling_power = x["close"] - x["low"]
@@ -855,7 +930,9 @@ def ADoscillator():
 
 
 def percentageR(days):
-    """Calculates the stochastic R
+    """
+    | Calculates the stochastic R
+    | Name: percentageR\_\ **days**
     
     :param days: Window size
     :type days: int
@@ -880,7 +957,9 @@ def percentageR(days):
 
 
 def RSI(days):
-    """Calculates the RSI
+    """
+    | Calculates the RSI
+    | Name: RSI\_\ **days**
 
     :param days: Window size
     :type days: int
@@ -910,7 +989,10 @@ def RSI(days):
 
 
 def special_k():
-    """Calculates the special k indicator"""
+    """
+    | Calculates the special k indicator
+    | Name: special_k
+    """
     def return_function(data):
         column_name = "special_k"
         if column_name not in data.columns:
